Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(459)

Unified Diff: remoting/protocol/host_control_dispatcher.h

Issue 9646013: Add the plumbing that will carry a clipboard item from a chromoting client to a host. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Move clipboard events to the control channel. Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/protocol/host_control_dispatcher.h
diff --git a/remoting/protocol/host_control_dispatcher.h b/remoting/protocol/host_control_dispatcher.h
index 2bda6555d20c2b85c6534455fc3617b8aec34d06..60d1a20c3a1bb366c5b41951911c7191746bb589 100644
--- a/remoting/protocol/host_control_dispatcher.h
+++ b/remoting/protocol/host_control_dispatcher.h
@@ -18,18 +18,26 @@ namespace remoting {
namespace protocol {
class BufferedSocketWriter;
+class ClipboardStub;
class ControlMessage;
class HostStub;
class Session;
// HostControlDispatcher dispatches incoming messages on the control
// channel to HostStub, and also implements ClientStub for outgoing
// messages.
class HostControlDispatcher : public ChannelDispatcherBase, public ClientStub {
public:
HostControlDispatcher();
virtual ~HostControlDispatcher();
+ // Set the ClipboardStub that will be called for each incoming clipboard
+ // message. Doesn't take ownership of |clipboard_stub|. It must outlive
Wez 2012/03/14 20:40:56 nit: ". It must" -> ", which must"
simonmorris 2012/03/14 21:20:21 Done.
+ // the dispatcher.
+ void set_clipboard_stub(ClipboardStub* clipboard_stub) {
+ clipboard_stub_ = clipboard_stub;
+ }
+
// Sets HostStub that will be called for each incoming control
// message. Doesn't take ownership of |host_stub|. It must outlive
// this dispatcher.
@@ -43,6 +51,7 @@ class HostControlDispatcher : public ChannelDispatcherBase, public ClientStub {
void OnMessageReceived(ControlMessage* message,
const base::Closure& done_task);
+ ClipboardStub* clipboard_stub_;
HostStub* host_stub_;
ProtobufMessageReader<ControlMessage> reader_;
@@ -18,18 +18,26 @@ namespace remoting {
class Session;
// HostControlDispatcher dispatches incoming messages on the control
-// channel to HostStub, and also implements ClientStub for outgoing
-// messages.
+// channel to HostStub or ClipboardStub, and also implements ClientStub for
+// outgoing messages.
class HostControlDispatcher : public ChannelDispatcherBase, public ClientStub {
public:

Powered by Google App Engine
This is Rietveld 408576698